%undefine __cmake_in_source_build
%global bootstrap 1
%bcond_without wayland_default
%bcond_without sddm_wayland_default

Summary:        QML based desktop and login manager
Name:           sddm
Version:        0.20.0
Release:        1%{?dist}
License:        GPLv2+

Url:            https://github.com/sddm/sddm
Source0:        %{url}/archive/v%{version}/%{name}-%{version}.tar.gz
Source2:       sddm.pam
Source3:       sddm-autologin.pam
Source4:       sddm.conf
Source5:       README.scripts
Source6:       sddm.sysconfig
Source7:       sddm-x11.conf
Source8:       sddm-systemd-sysusers.conf

Patch0001:      1797.patch
Patch0002:      0001-Delay-for-logind-and-fallback-to-seat0.patch
Patch0003:      sddm-0.20.0-config.patch
Patch0004:      sddm-0.18.0-environment_file.patch
Patch0005:      sddm-rpmostree-tmpfiles-hack.patch

Provides: service(graphical-login) = sddm

BuildRequires:  cmake >= 2.8.8, extra-cmake-modules, libxcb-devel
BuildRequires:  pam-devel, pkgconfig(libsystemd), pkgconfig(systemd)
BuildRequires:  /usr/bin/rst2man
BuildRequires:  qt5-qtbase-devel >= 5.6, qt5-qtdeclarative-devel >= 5.6, qt5-qttools-devel >= 5.6
BuildRequires:  shadow-utils, systemd, systemd-rpm-macros
%if ! %{?bootstrap: 1}
BuildRequires: desktop-backgrounds-compat
%endif
BuildRequires: GraphicsMagick

%if ! %{?bootstrap: 1}
Requires: desktop-backgrounds-compat
%endif
Requires: system-logos
Requires: systemd
Requires: xorg-x11-xinit
Suggests: qt5-qtvirtualkeyboard
%{?systemd_requires}

Requires(pre): shadow-utils


Requires: sddm-greeter-displayserver
%if ! %{with sddm_wayland_default}
Suggests: sddm-x11
%else
Suggests: sddm-wayland-generic
%endif

%description
SDDM is a modern graphical display manager aiming to be fast, simple and
beautiful. It uses modern technologies like QtQuick, which in turn gives the
designer the ability to create smooth, animated user interfaces.

%package wayland-generic
Summary: Generic Wayland SDDM greeter configuration
Provides: sddm-greeter-displayserver
Conflicts: sddm-greeter-displayserver
Requires: weston
Requires: %{name} = %{version}-%{release}
BuildArch: noarch

%description wayland-generic
This package contains configuration and dependencies for SDDM
to use Weston for the greeter display server.

This is the generic default Wayland configuration provided
by SDDM.

%package x11
Summary: X11 SDDM greeter configuration
Provides: sddm-greeter-displayserver
Conflicts: sddm-greeter-displayserver
Requires: xorg-x11-server-Xorg
Requires: %{name} = %{version}-%{release}
BuildArch: noarch

%description x11
This package contains configuration and dependencies for SDDM
to use X11 for the greeter display server.

%package themes
Summary: SDDM Themes
Requires: %{name} = %{version}-%{release}
BuildArch: noarch
%description themes
A collection of sddm themes, including: elarun, maldives, maya


%prep
%autosetup -p1 %{?commitdate:-n %{name}-%{commit}}

%if ! %{?bootstrap: 1}
cp -v /usr/share/backgrounds/default.png  \
      src/greeter/theme/background.png
ls -sh src/greeter/theme/background.png
gm mogrify -resize 1920x1200 src/greeter/theme/background.png
ls -sh src/greeter/theme/background.png
%endif

%build
%cmake \
  -DBUILD_MAN_PAGES:BOOL=ON \
  -DCMAKE_BUILD_TYPE:STRING="Release" \
  -DENABLE_JOURNALD:BOOL=ON \
  -DSESSION_COMMAND:PATH=/etc/X11/xinit/Xsession \
  -DWAYLAND_SESSION_COMMAND:PATH=/etc/sddm/wayland-session

%cmake_build


%install
%cmake_install

mkdir -p %{buildroot}%{_sysconfdir}/sddm.conf.d
mkdir -p %{buildroot}%{_prefix}/lib/sddm/sddm.conf.d
install -Dpm 644 %{SOURCE2} %{buildroot}%{_sysconfdir}/pam.d/sddm
install -Dpm 644 %{SOURCE3} %{buildroot}%{_sysconfdir}/pam.d/sddm-autologin
install -Dpm 644 %{SOURCE4} %{buildroot}%{_sysconfdir}/sddm.conf
install -Dpm 644 %{SOURCE5} %{buildroot}%{_datadir}/sddm/scripts/README.scripts
install -Dpm 644 %{SOURCE6} %{buildroot}%{_sysconfdir}/sysconfig/sddm
install -Dpm 644 %{SOURCE7} %{buildroot}%{_prefix}/lib/sddm/sddm.conf.d/x11.conf
mkdir -p %{buildroot}/run/sddm
mkdir -p %{buildroot}%{_localstatedir}/lib/sddm
mkdir -p %{buildroot}%{_sysconfdir}/sddm/
cp -a %{buildroot}%{_datadir}/sddm/scripts/* \
      %{buildroot}%{_sysconfdir}/sddm/
rm -fv %{buildroot}%{_sysconfdir}/sddm/Xsession

%pre
%sysusers_create_compat %{SOURCE8}

%post
%systemd_post sddm.service
(grep \
   -e '^Current=system$' \
   -e '^\[XDisplay\]$' \
   -e '^\[WaylandDisplay\]$' \
   %{_sysconfdir}/sddm.conf > /dev/null && \
 sed -i.rpmsave \
   -e 's|^Current=system$|#Current=01-breeze-system|' \
   -e 's|^\[XDisplay\]$|\[X11\]|' \
   -e 's|^\[WaylandDisplay\]$|\[Wayland\]|' \
   %{_sysconfdir}/sddm.conf
) ||:

%preun
%systemd_preun sddm.service

%postun
%systemd_postun sddm.service

%files
%license LICENSE
%doc README.md CONTRIBUTORS
%dir %{_sysconfdir}/sddm/
%dir %{_sysconfdir}/sddm.conf.d
%dir %{_prefix}/lib/sddm/sddm.conf.d
%config(noreplace)   %{_sysconfdir}/sddm/*
%config(noreplace)   %{_sysconfdir}/sddm.conf
%config(noreplace)   %{_sysconfdir}/pam.d/sddm
%config(noreplace)   %{_sysconfdir}/pam.d/sddm-autologin
%config(noreplace)   %{_sysconfdir}/pam.d/sddm-greeter
%config(noreplace) %{_sysconfdir}/sysconfig/sddm
%{_sysconfdir}/dbus-1/system.d/org.freedesktop.DisplayManager.conf
%{_bindir}/sddm
%{_bindir}/sddm-greeter
%{_libexecdir}/sddm-helper
%{_libexecdir}/sddm-helper-start-wayland
%{_libexecdir}/sddm-helper-start-x11user
%{_tmpfilesdir}/sddm.conf
%{_sysusersdir}/sddm.conf
%attr(0711, root, sddm) %dir /run/sddm
%attr(1770, sddm, sddm) %dir %{_localstatedir}/lib/sddm
%{_unitdir}/sddm.service
%{_qt5_archdatadir}/qml/SddmComponents/
%dir %{_datadir}/sddm
%{_datadir}/sddm/faces/
%{_datadir}/sddm/flags/
%{_datadir}/sddm/scripts/
%dir %{_datadir}/sddm/themes/
%{_datadir}/sddm/translations/
%{_mandir}/man1/sddm.1*
%{_mandir}/man1/sddm-greeter.1*
%{_mandir}/man5/sddm.conf.5*
%{_mandir}/man5/sddm-state.conf.5*

%files wayland-generic

%files x11
%{_prefix}/lib/sddm/sddm.conf.d/x11.conf

%files themes
%{_datadir}/sddm/themes/elarun/
%{_datadir}/sddm/themes/maldives/
%{_datadir}/sddm/themes/maya/


%changelog
* Fri Nov 17 2023 Chair <chairou@tencent.com> - 0.20.0-1
- Init
